pub struct GetChatCompletionMessagesQuery {
pub after: Option<String>,
pub limit: Option<u32>,
pub order: Option<GetChatCompletionMessagesOrder>,
}Expand description
Query parameters for getting chat completion messages.
Fields
after: Option<String>Identifier for the last message from the previous pagination request.
limit: Option<u32>Number of messages to retrieve.
order: Option<GetChatCompletionMessagesOrder>Sort order for messages by timestamp. Use asc for ascending order or desc for descending order. Defaults to asc.