pub struct GetChatCompletionMessagesQueryArgs { /* private fields */ }Expand description
Builder for GetChatCompletionMessagesQuery.
Implementations
Sourceimpl GetChatCompletionMessagesQueryArgs
impl GetChatCompletionMessagesQueryArgs
Sourcepub fn after<VALUE>(
&mut self,
value: VALUE,
) -> &mut GetChatCompletionMessagesQueryArgs
pub fn after<VALUE>( &mut self, value: VALUE, ) -> &mut GetChatCompletionMessagesQueryArgs
Identifier for the last message from the previous pagination request.
Sourcepub fn limit<VALUE>(
&mut self,
value: VALUE,
) -> &mut GetChatCompletionMessagesQueryArgs
pub fn limit<VALUE>( &mut self, value: VALUE, ) -> &mut GetChatCompletionMessagesQueryArgs
Number of messages to retrieve.
Sourcepub fn order<VALUE>(
&mut self,
value: VALUE,
) -> &mut GetChatCompletionMessagesQueryArgswhere
VALUE: Into<GetChatCompletionMessagesOrder>,
pub fn order<VALUE>(
&mut self,
value: VALUE,
) -> &mut GetChatCompletionMessagesQueryArgswhere
VALUE: Into<GetChatCompletionMessagesOrder>,
Sort order for messages by timestamp. Use asc for ascending order or desc for descending order. Defaults to asc.
Sourcepub fn build(&self) -> Result<GetChatCompletionMessagesQuery, OpenAIError>
pub fn build(&self) -> Result<GetChatCompletionMessagesQuery, OpenAIError>